@@ -439,6 +439,7 @@ public class SynapseConfigUtils {
                     }
 
                     connection.setHostnameVerifier(new javax.net.ssl.HostnameVerifier() {
+                        @Override
                         public boolean verify(String hostname, javax.net.ssl.SSLSession session) {
                             if (log.isTraceEnabled()) {
                                 log.trace("HostName verification disabled");
@@ -897,5 +898,20 @@ public class SynapseConfigUtils {
         }
         return false;
     }
+
+    /**
+     * Retrieve injected environment variables when detecting parameters with "$" prefix
+     *
+     * @param parameter parameter to be populated with retrieved environment variable
+     * @return string value in environment variables
+     */
+    public static String fetchEnvironmentVariables(String parameter) {
+        String injectedValue = parameter;
+        if (parameter.startsWith(SynapseConstants.SYSTEM_VARIABLE_PREFIX)) {
+            String extractedEnvVariableKey = parameter.substring(parameter.lastIndexOf(":") + 1);
+            injectedValue = System.getenv(extractedEnvVariableKey);
+        }
+        return injectedValue;
+    }
 }
 
